#undef ENLIGHTENMENT_VERSION

#undef HAVE_STDARGS

#undef HAVE_LIBESD

#undef HAVE_SM

#undef ENLIGHTENMENT_MAJOR

#undef ENLIGHTENMENT_MINOR

#undef ENLIGHTENMENT_MICRO

#undef AUTOUPGRADE

#undef WITH_TARTY_WARP

#undef WITH_ZOOM
